==> topology-segment-routing-0.13.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/sr/rev130819/sr/node/attributes/segments/segment/specification/prefix/_case/Prefix.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpPrefix;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.Segments;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>network-topology-sr</b>
 * <pre>
 * container prefix {
 *   leaf prefix {
 *     type inet:ip-prefix;
 *   }
 *   leaf node-sid {
 *     type boolean;
 *     default false;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>network-topology-sr/sr-node-attributes/segments/segment-specification/prefix-case/prefix</i>
 *
 * <p>To create instances of this class use {@link PrefixBuilder}.
 * @see PrefixBuilder
 *
 */
public interface Prefix
    extends
    ChildOf<Segments>,
    Augmentable<Prefix>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("prefix");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case.Prefix> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case.Prefix.class;
    }
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpPrefix</code> <code>prefix</code>, or <code>null</code> if not present
     */
    @Nullable IpPrefix getPrefix();
    
    /**
     * @return <code>java.lang.Boolean</code> <code>nodeSid</code>, or <code>null</code> if not present
     */
    @Nullable Boolean isNodeSid();

}

==> topology-segment-routing-0.14.4-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/sr/rev130819/sr/node/attributes/segments/segment/specification/prefix/_case/Prefix.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Override;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpPrefix;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.Segments;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>network-topology-sr</b>
 * <pre>
 * container prefix {
 *   leaf prefix {
 *     type inet:ip-prefix;
 *   }
 *   leaf node-sid {
 *     type boolean;
 *     default false;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>network-topology-sr/sr-node-attributes/segments/segment-specification/prefix-case/prefix</i>
 *
 * <p>To create instances of this class use {@link PrefixBuilder}.
 * @see PrefixBuilder
 *
 */
public interface Prefix
    extends
    ChildOf<Segments>,
    Augmentable<Prefix>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("prefix");

    @Override
    default Class<org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case.Prefix> implementedInterface() {
        return org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.sr.rev130819.sr.node.attributes.segments.segment.specification.prefix._case.Prefix.class;
    }
    
    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.IpPrefix</code> <code>prefix</code>, or <code>null</code> if not present
     */
    IpPrefix getPrefix();
    
    /**
     * @return <code>java.lang.Boolean</code> <code>nodeSid</code>, or <code>null</code> if not present
     */
    Boolean isNodeSid();

}
